@@ -34,7 +34,9 @@ pub struct InterfaceTypeDef {
 impl From<InterfaceTypeDef> for InterfaceDefinition {
     fn from(itf: InterfaceTypeDef) -> Self {
         let mut itf_def = InterfaceDefinition::new(itf.name.into());
-        itf_def.description(itf.description.map(String::from));
+        if let Some(description) = itf.description {
+            itf_def.description(description.into())
+        }
         itf.fields_def
             .into_iter()
             .for_each(|f| itf_def.field(f.into()));
